@@ -50,7 +50,7 @@ class BindingCollection(dict, Dict[Bindings, Set[str]]):
 
 class BaseTkinterWidget(tk.Widget, ABC):
     # noinspection PyMissingConstructor
-    def __init__(self, Color: dict = None):
+    def __init__(self, Color: Dict[str, str] = None):
         if Color: self.configure(**Color)
 
     __bindings__: BindingCollection = BindingCollection()
@@ -103,6 +103,8 @@ class BaseTkinterWidget(tk.Widget, ABC):
 
 
 
+    @property
+    def size(self) -> Size: return Size.Create(self.width, self.height)
     @property
     def width(self) -> int: return self.winfo_width()
     @property
@@ -113,7 +115,8 @@ class BaseTkinterWidget(tk.Widget, ABC):
     @property
     def y(self) -> int: return self.winfo_rooty()
 
-    def size(self) -> Size: return Size.Create(self.width, self.height)
+
+
     def show(self, **kwargs) -> bool:
         """
         Shows the current widget or _root_frame, based on the current geometry manager.
@@ -381,7 +384,7 @@ class BaseTkinterWidget(tk.Widget, ABC):
 class BaseTextTkinterWidget(BaseTkinterWidget):
     _txt: tk.StringVar
     # noinspection PyMissingConstructor
-    def __init__(self, *, Override_var: tk.StringVar = None, text: str, Color: dict = None, configure: bool = True):
+    def __init__(self, text: str, Override_var: Optional[tk.StringVar], Color: Optional[Dict[str, str]], configure: bool = True):
         if Override_var is not None: self._txt = Override_var
         else: self._txt = tk.StringVar(master=self, value=text)
 
